==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/LinksActivateActivate.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefHints;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksActivateActivate
 */
@JsonPropertyOrder({ LinksActivateActivate.JSON_PROPERTY_HINTS, LinksActivateActivate.JSON_PROPERTY_HREF,
        LinksActivateActivate.JSON_PROPERTY_NAME, LinksActivateActivate.JSON_PROPERTY_TEMPLATED,
        LinksActivateActivate.JSON_PROPERTY_TYPE })
@JsonTypeName("LinksActivate_activate")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksActivateActivate implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_HINTS = "hints";
    private HrefHints hints;

    public static final String JSON_PROPERTY_HREF = "href";
    private String href;

    public static final String JSON_PROPERTY_NAME = "name";
    private String name;

    public static final String JSON_PROPERTY_TEMPLATED = "templated";
    private Boolean templated;

    public static final String JSON_PROPERTY_TYPE = "type";
    private String type;

    public LinksActivateActivate() {
    }

    public LinksActivateActivate hints(HrefHints hints) {

        this.hints = hints;
        return this;
    }

    /**
     * Get hints
     *
     * @return hints
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_HINTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefHints getHints() {
        return hints;
    }

    @JsonProperty(JSON_PROPERTY_HINTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setHints(HrefHints hints) {
        this.hints = hints;
    }

    public LinksActivateActivate href(String href) {

        this.href = href;
        return this;
    }

    /**
     * Link URI
     *
     * @return href
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "Link URI")
    @JsonProperty(JSON_PROPERTY_HREF)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getHref() {
        return href;
    }

    @JsonProperty(JSON_PROPERTY_HREF)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setHref(String href) {
        this.href = href;
    }

    public LinksActivateActivate name(String name) {

        this.name = name;
        return this;
    }

    /**
     * Link name
     *
     * @return name
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Link name")
    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getName() {
        return name;
    }

    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setName(String name) {
        this.name = name;
    }

    public LinksActivateActivate templated(Boolean templated) {

        this.templated = templated;
        return this;
    }

    /**
     * Indicates whether the Link Object&#39;s &#x60;href&#x60; property is a URI template.
     *
     * @return templated
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Indicates whether the Link Object's `href` property is a URI template.")
    @JsonProperty(JSON_PROPERTY_TEMPLATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getTemplated() {
        return templated;
    }

    @JsonProperty(JSON_PROPERTY_TEMPLATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTemplated(Boolean templated) {
        this.templated = templated;
    }

    public LinksActivateActivate type(String type) {

        this.type = type;
        return this;
    }

    /**
     * The media type of the link. If omitted, it is implicitly &#x60;application/json&#x60;.
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The media type of the link. If omitted, it is implicitly `application/json`.")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(String type) {
        this.type = type;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksActivateActivate linksActivateActivate = (LinksActivateActivate) o;
        return Objects.equals(this.hints, linksActivateActivate.hints)
                && Objects.equals(this.href, linksActivateActivate.href)
                && Objects.equals(this.name, linksActivateActivate.name)
                && Objects.equals(this.templated, linksActivateActivate.templated)
                && Objects.equals(this.type, linksActivateActivate.type);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(hints, href, name, templated, type);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksActivateActivate {\n");
        sb.append("    hints: ").append(toIndentedString(hints)).append("\n");
        sb.append("    href: ").append(toIndentedString(href)).append("\n");
        sb.append("    name: ").append(toIndentedString(name)).append("\n");
        sb.append("    templated: ").append(toIndentedString(templated)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/LinksActivateActivate.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefHints;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksActivateActivate
 */
@JsonPropertyOrder({ LinksActivateActivate.JSON_PROPERTY_HINTS, LinksActivateActivate.JSON_PROPERTY_HREF,
        LinksActivateActivate.JSON_PROPERTY_NAME, LinksActivateActivate.JSON_PROPERTY_TEMPLATED,
        LinksActivateActivate.JSON_PROPERTY_TYPE })
@JsonTypeName("LinksActivate_activate")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class LinksActivateActivate implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_HINTS = "hints";
    private HrefHints hints;

    public static final String JSON_PROPERTY_HREF = "href";
    private String href;

    public static final String JSON_PROPERTY_NAME = "name";
    private String name;

    public static final String JSON_PROPERTY_TEMPLATED = "templated";
    private Boolean templated;

    public static final String JSON_PROPERTY_TYPE = "type";
    private String type;

    public LinksActivateActivate() {
    }

    public LinksActivateActivate hints(HrefHints hints) {

        this.hints = hints;
        return this;
    }

    /**
     * Get hints
     *
     * @return hints
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_HINTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefHints getHints() {
        return hints;
    }

    @JsonProperty(JSON_PROPERTY_HINTS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setHints(HrefHints hints) {
        this.hints = hints;
    }

    public LinksActivateActivate href(String href) {

        this.href = href;
        return this;
    }

    /**
     * Link URI
     *
     * @return href
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "Link URI")
    @JsonProperty(JSON_PROPERTY_HREF)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getHref() {
        return href;
    }

    @JsonProperty(JSON_PROPERTY_HREF)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setHref(String href) {
        this.href = href;
    }

    public LinksActivateActivate name(String name) {

        this.name = name;
        return this;
    }

    /**
     * Link name
     *
     * @return name
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Link name")
    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getName() {
        return name;
    }

    @JsonProperty(JSON_PROPERTY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setName(String name) {
        this.name = name;
    }

    public LinksActivateActivate templated(Boolean templated) {

        this.templated = templated;
        return this;
    }

    /**
     * Indicates whether the Link Object&#39;s &#x60;href&#x60; property is a URI template.
     *
     * @return templated
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Indicates whether the Link Object's `href` property is a URI template.")
    @JsonProperty(JSON_PROPERTY_TEMPLATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getTemplated() {
        return templated;
    }

    @JsonProperty(JSON_PROPERTY_TEMPLATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTemplated(Boolean templated) {
        this.templated = templated;
    }

    public LinksActivateActivate type(String type) {

        this.type = type;
        return this;
    }

    /**
     * The media type of the link. If omitted, it is implicitly &#x60;application/json&#x60;.
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The media type of the link. If omitted, it is implicitly `application/json`.")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(String type) {
        this.type = type;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksActivateActivate linksActivateActivate = (LinksActivateActivate) o;
        return Objects.equals(this.hints, linksActivateActivate.hints)
                && Objects.equals(this.href, linksActivateActivate.href)
                && Objects.equals(this.name, linksActivateActivate.name)
                && Objects.equals(this.templated, linksActivateActivate.templated)
                && Objects.equals(this.type, linksActivateActivate.type);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(hints, href, name, templated, type);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksActivateActivate {\n");
        sb.append("    hints: ").append(toIndentedString(hints)).append("\n");
        sb.append("    href: ").append(toIndentedString(href)).append("\n");
        sb.append("    name: ").append(toIndentedString(name)).append("\n");
        sb.append("    templated: ").append(toIndentedString(templated)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
